xsdata.formats.dataclass.parsers package
========================================

Submodules
----------

.. toctree::
   :maxdepth: 4

   xsdata.formats.dataclass.parsers.config
   xsdata.formats.dataclass.parsers.json
   xsdata.formats.dataclass.parsers.nodes
   xsdata.formats.dataclass.parsers.utils
   xsdata.formats.dataclass.parsers.xml

Module contents
---------------

.. automodule:: xsdata.formats.dataclass.parsers
   :members:
   :undoc-members:
   :show-inheritance:
